@@ -17,7 +17,7 @@ def dashboards(file_data, sdmonitor, existing_dashboards, restore_unowned):
 
     username = userdata["user"]["username"]
     dashboards = [dboard for dboard in file_data if
-                  restore_unowned or "username" in dboard and dboard["username"] == username]
+                  restore_unowned or "username" in dboard and username in dboard["username"]]
     total = len(dashboards)
     for i, dashboard in enumerate(dashboards):
         name = dashboard['name']
